@@ -2,6 +2,9 @@
 ''''A useful collection of tools to aid in manipulating contour networks
 This is admittedly less coherent/documented and more "bleeding edge" than ImageContour.py'''
 
+from __future__ import absolute_import
+from __future__ import print_function
+
 import os
 from copy import deepcopy
 #import cPickle # old pickle version
@@ -13,7 +16,7 @@ from collections import Counter
 
 import numpy as np
 
-from matplotlib import mpl
+import matplotlib as mpl
 import matplotlib.pyplot as plt
 
 #from list_utils:
@@ -24,19 +27,19 @@ from np_utils import ( totuple, interp, interpGen, flatten, ziptranspose,
 #from gen_utils
 from np_utils import minmax
 #from func_utils
-from np_utils import compose,kwdPop
+from np_utils import compose, kwdPop
 #from np_utils:
 from np_utils import ( polyArea, polyPerimeter, polyCentroid,
                        polyCirculationDirection,pointDistance,
                        limitInteriorPoints, limitInteriorPointsInterpolating,
                        addBorder, getValuesAroundPointInArray )
 
-import ImageContour
-from temperatureCmaps import temperatureCmap,temperatureDarkCmap,temperatureLightCmap
+from . import ImageContour
+from .temperatureCmaps import temperatureCmap,temperatureDarkCmap,temperatureLightCmap
 
 def GetValuesAroundSCPoint(watershed2d,point,wrapX=False,wrapY=False):
     vals = getValuesAroundPointInArray(watershed2d,point,wrapX,wrapY)
-    return ( tuple(vals.tolist()) if vals!=None else (None,None,None) )
+    return ( tuple(vals.tolist()) if vals is not None else (None,None,None) )
 
 def BreakLinesIntoEvenPieces(points,nSegments):
     '''Take the points from a multi-line and re-interpolate the
@@ -65,7 +68,7 @@ def _getReportPixel(arr):
     return report_pixel
 
 def _prepMinMaxForColoredPlot(vals,MinMax=None):
-    if MinMax==None:
+    if MinMax is None:
         mmin,mmax = minmax(deletecases(vals,[None]))
         MinMax = minmax([mmin,-mmin,mmax,-mmax])
     return MinMax
@@ -75,7 +78,7 @@ def _prepColorsForColoredPlot(vals,kwds,MinMax=None):
     Min,Max = _prepMinMaxForColoredPlot(vals,MinMax)
     norm = mpl.colors.Normalize(Min, Max)
     scalarMap = plt.cm.ScalarMappable(norm=norm, cmap=cmap)
-    colorList = [ ( None if v==None else
+    colorList = [ ( None if v is None else
                     scalarMap.to_rgba(v) )
                  for v in vals ]
     return colorList
@@ -371,7 +374,7 @@ class CellNetwork(object):
         '''Get a list off subcontours (indexes) that belong to degenerate contours (either points or lines)'''
         problemSCs = set()
         problemVals = set()
-        for v,scInds in self.contourOrderingByValue.iteritems():
+        for v,scInds in self.contourOrderingByValue.items():
             if len(scInds)<3:
                 scInds = [i[0] for i in scInds] # before, this also contained subcontour direction information
                 if sum([ self.subContours[i].numPoints-1 for i in scInds ]) < 3:
@@ -393,7 +396,7 @@ class CellNetwork(object):
         if checkForDegeneracy:
             problemVals,problemValuePairs = self.CheckForDegenerateContours()
             if problemVals!=[]:
-                print 'Values with degenerate contours:',problemVals
+                print('Values with degenerate contours:',problemVals)
                 raise DegenerateNetworkException('Degenerate contours (zero area) found between these cellIDs!'+repr(problemValuePairs))
     
     def CleanUpEmptySubContours(self):
@@ -405,12 +408,12 @@ class CellNetwork(object):
         scIndexMap = {}
         count = 0
         for i in range(len(self.subContours)):
-            if self.subContours[i]!=None:
+            if self.subContours[i] is not None:
                 scIndexMap[i] = count
                 count+=1
                 
         # Now go through and delete all the dead sc's
-        self.subContours = [ sc for sc in self.subContours if sc!=None ]
+        self.subContours = [ sc for sc in self.subContours if sc is not None ]
         
         # Now, go in and reindex contourOrderingByValue
         for v in self.contourOrderingByValue.keys():
@@ -455,13 +458,13 @@ class CellNetwork(object):
         
         # And now, replace occurrences of valuesToRemove in the sc.values by 1 (background) instead
         for sc in self.subContours:
-            if sc!=None:
+            if sc is not None:
                 len_intersect = len(set(sc.values).intersection(valuesToRemove))
                 if len_intersect==1:
                     sc.values = tuple(sorted([ (1 if v in valuesToRemove else v)
                                               for v in sc.values]))
                 elif len_intersect==2:
-                    print 'Now how did that happen? We just filtered those out!'
+                    print('Now how did that happen? We just filtered those out!')
                     return
                 
                 startNew = set(sc.startPointValues).difference(valuesToRemove)
@@ -552,10 +555,10 @@ class CellNetwork(object):
             # Find all the subcountours that share triple junctions with the start and/or end points of scDel:
             connectedSCsToStart = [ (i,sc)
                                    for i,sc in enumerate(self.subContours)
-                                   if sc!=scDel and sc!=None and ( scDel.points[0] in [sc.points[0],sc.points[-1]] ) ]
+                                   if sc != scDel and sc is not None and ( scDel.points[0] in [sc.points[0],sc.points[-1]] ) ]
             connectedSCsToEnd = [ (i,sc)
                                  for i,sc in enumerate(self.subContours)
-                                 if sc!=scDel and sc!=None and ( scDel.points[-1] in [sc.points[0],sc.points[-1]] ) ]
+                                 if sc != scDel and sc is not None and ( scDel.points[-1] in [sc.points[0],sc.points[-1]] ) ]
             #print len(connectedSCsToStart),len(connectedSCsToEnd)
             
             for scDelPtInd,connectedSCs in ((0,connectedSCsToStart),(-1,connectedSCsToEnd)):
@@ -563,7 +566,7 @@ class CellNetwork(object):
                     connPtInd = ( 0 if s.points[0]==scDel.points[scDelPtInd] else -1 ) # it has to be either the start or the end of a sc
                     self.subContours[i].points[connPtInd] = scDelMidpoint
         else:
-            print 'NOT IMPLEMENTED'
+            print('NOT IMPLEMENTED')
             if leaveTinyFlipFlopContour:
                 pass
             else:
@@ -640,8 +643,8 @@ class CellNetwork(object):
             x = [ p[0]-0.5 for p in contourPoints[v] ]
             y = [ p[1]-0.5 for p in contourPoints[v] ]
             x,y = (y,x) if reverseXY else (x,y)
-            if colorList!=None:
-                if colorList[i]==None: # skip cells with no color
+            if colorList is not None:
+                if colorList[i] is None: # skip cells with no color
                     continue
                 kwds['color'] = colorList[i] # override the default color
             _=plotFunction( y,x, *args, **kwds )
@@ -677,7 +680,7 @@ class CellNetwork(object):
         
         plotList = []
         for color,sc in zip(colorList,self.subContours):
-            if color!=None:
+            if color is not None:
                 scplot = ( sc.plotT if reverseXY else sc.plot )
                 kwds['color'],kwds['linewidth'] = color,linewidth
                 plotList.append(  scplot(*args,**kwds)  )
@@ -718,7 +721,7 @@ class CellNetwork(object):
         rPlot = np.zeros(waterArr.shape,dtype=np.float)
         for i,v in enumerate(sorted(self.contourOrderingByValue.keys())):
             p,pErr = pressures[i],pressureErrors[i]
-            if p!=None:
+            if p is not None:
                 wh = np.where(waterArr==v)
                 nPts = len(wh[0])
                 rPlot[wh] = ( np.random.normal(p,pErr,nPts) if pErr!=0 else
@@ -757,7 +760,7 @@ def GetCellNetworkFromFlatData(fdcn):
     
     return CellNetwork( **{ 'subContours' : [ SubContour(**j) for j in fdcn['subContours'] ],
                             'quadPoints' : [ QuadPoint(**j) for j in fdcn['quadPoints'] ],
-                            'contourOrderingByValue' : { int(k):v for k,v in fdcn['contourOrderingByValue'].iteritems() },
+                            'contourOrderingByValue' : { int(k):v for k,v in fdcn['contourOrderingByValue'].items() },
                             'allValues': fdcn['allValues'], } )
 
 def GetCellNetworkListStaticFromJsonFile(filename):
@@ -772,8 +775,8 @@ def GetCellNetworkListPrevNextFromJsonFile(filename):
         cnListPrevFlat,cnListNextFlat = json.load(fid)
     cnListPrev,cnListNext = [ [ GetCellNetworkFromFlatData(fdcn)
                                for fdcn in cnListFlat ]
-                             for cnListFlat in cnListPrevFlat,cnListNextFlat ]
-    return cnListPN
+                             for cnListFlat in (cnListPrevFlat,cnListNextFlat) ]
+    return cnListPrev,cnListNext
 
 def SubContourListfromCVLSList(cVLS_List,startPointValues_List=[],endPointValues_List=[]):
     '''Get a list of SubContour objects from an old list of cVLS's'''
@@ -796,7 +799,7 @@ def GetCellNetwork( watershed2d,allValues=None,bgVals=(0,1),scale=1,offset=(0,0)
        allValues is optional and specifies which value in the array to include in the network
        bgVals are the values ignored as background (at least 0 should always be used)
        scale and offset define a non-rotational transform over the output points'''
-    if allValues==None:
+    if allValues is None:
         allValues = np.unique(watershed2d)
     allValues = np.array(allValues).tolist() # force numpy arrays to lists
     allValues = [ v for v in allValues if v not in bgVals ] # skip the background
@@ -893,10 +896,7 @@ def GetCellNetworkWithCellsRemoved(cn,cellsToRemove,bgVals):
     cnClip.subContours = [ ( sc if set(sc.values).difference(newBgSet) else
                              None )
                           for sc in cnClip.subContours ]
-    print [(0 if None else 1) for sc in cnClip.subContours]
     # Delete cells from contourOrderingByValue and allValues and then re-index everything
-    print cellsToRemove
-    
     for c in cellsToRemove:
         del cnClip.contourOrderingByValue[c]
     cnClip.allValues = [ v for v in cnClip.allValues if v not in cellsToRemove ]
@@ -919,7 +919,7 @@ def GetCellNetworkListWithLimitedPointsBetweenNodes(cellNetworkList,splitLength=
     allPairs = sorted(set( [ tuple(sc.values) for cn in cellNetworkList for sc in cn.subContours ] )) # Value pairs...
     
     # Build the numInteriorPointsDict:
-    if fixedNumInteriorPoints!=None:
+    if fixedNumInteriorPoints is not None:
         numInteriorPointsDict = { p:fixedNumInteriorPoints for p in allPairs }
     else:
         # minLength is the number of points of the shortest subcountour between cells p[0] and p[1] from all frames
@@ -937,15 +937,15 @@ def GetCellNetworkListWithLimitedPointsBetweenNodes(cellNetworkList,splitLength=
     if checkForDegeneracy:
         problemValsList,problemValuePairsList = ziptranspose([ cn.CheckForDegenerateContours() for cn in cellNetworkListNew ])
         if flatten(problemValsList)!=[]:
-            print 'All degenerate values:',sorted(set(flatten(problemValsList)))
-            print 'Degenerate values by frame:'
+            print('All degenerate values:',sorted(set(flatten(problemValsList))))
+            print('Degenerate values by frame:')
             for i,problemVals in enumerate(problemValsList):
                 if problemVals!=[]:
-                    print ' ',i,':',problemVals
-            print 'Degenerate contours (zero area) found between these cellIDs on these frames!'
+                    print(' ',i,':',problemVals)
+            print('Degenerate contours (zero area) found between these cellIDs on these frames!')
             for i,problemValuePairs in enumerate(problemValuePairsList):
                 if problemValuePairs!=[]:
-                    print ' ',i,':',problemValuePairs
+                    print(' ',i,':',problemValuePairs)
             raise DegenerateNetworkException('Degeneracy check failed!')
     
     return cellNetworkListNew
@@ -973,15 +973,15 @@ def GetCellNetworkListWithLimitedPointsBetweenNodes_FullInterpolation(cellNetwor
     if checkForDegeneracy:
         problemValsList,problemValuePairsList = ziptranspose([ cn.CheckForDegenerateContours() for cn in cellNetworkListNew ])
         if flatten(problemValsList)!=[]:
-            print 'All degenerate values:',sorted(set(flatten(problemValsList)))
-            print 'Degenerate values by frame:'
+            print('All degenerate values:',sorted(set(flatten(problemValsList))))
+            print('Degenerate values by frame:')
             for i,problemVals in enumerate(problemValsList):
                 if problemVals!=[]:
-                    print ' ',i,':',problemVals
-            print 'Degenerate contours (zero area) found between these cellIDs on these frames!'
+                    print(' ',i,':',problemVals)
+            print('Degenerate contours (zero area) found between these cellIDs on these frames!')
             for i,problemValuePairs in enumerate(problemValuePairsList):
                 if problemValuePairs!=[]:
-                    print ' ',i,':',problemValuePairs
+                    print(' ',i,':',problemValuePairs)
             raise DegenerateNetworkException('Degeneracy check failed!')
     
     return cellNetworkListNew
@@ -1022,15 +1022,15 @@ def GetMatchedCellNetworkListsWithLimitedPointsBetweenNodes(cellNetworkListPrev,
                                  for i in collectPreviousNextResults(problemValuePairsListPrev,problemValuePairsListNext) ]
         
         if flatten(problemValsList)!=[]:
-            print 'All degenerate values:',sorted(set(flatten(problemValsList)))
-            print 'Degenerate values by frame:'
+            print('All degenerate values:',sorted(set(flatten(problemValsList))))
+            print('Degenerate values by frame:')
             for i,problemVals in enumerate(problemValsList):
                 if problemVals!=[]:
-                    print ' ',i,':',problemVals
-            print 'Degenerate contours (zero area) found between these cellIDs on these frames!'
+                    print(' ',i,':',problemVals)
+            print('Degenerate contours (zero area) found between these cellIDs on these frames!')
             for i,problemValuePairs in enumerate(problemValuePairsList):
                 if problemValuePairs!=[]:
-                    print ' ',i,':',problemValuePairs
+                    print(' ',i,':',problemValuePairs)
             raise DegenerateNetworkException('Degeneracy check failed!')
     
     return cnListPrevNew,cnListNextNew
@@ -1086,7 +1086,7 @@ def FindMatchesAndRemovals(cnA,cnB):
     for nIntersections,multiFailString in [ ( 2, 'with the same start/end point values:' ),
                                             ( 1, 'with one common endpoint:'             ),
                                             ( 0, 'without common start/endpoints:'       ),]:
-        commonPairs = set(pairGroupsA.keys()).intersection(pairGroupsB.keys())
+        commonPairs = set(pairGroupsA.keys()).intersection(list(pairGroupsB.keys()))
         for pair in commonPairs:
             # Look for any and all connections (i,j) between pairGroupsA[pair] and pairGroupsB[pair]
             # each pair here is a successful match between a subcontour in A and another in B
@@ -1112,16 +1112,16 @@ def FindMatchesAndRemovals(cnA,cnB):
                 matchedA += matchA
                 matchedB += matchB
             elif len(matchInds)>1:
-                print 'Not recoverable'
-                print "sc's matches multiple sc's in opposing list " + multiFailString,pair,matchA,matchB
+                print('Not recoverable')
+                print("sc's matches multiple sc's in opposing list " + multiFailString,pair,matchA,matchB)
                 # Print more details...
-                print 'matchInds:',matchInds
+                print('matchInds:',matchInds)
                 for cn,matc,ABstr in [ (cnA,matchA,'A'),
                                        (cnB,matchB,'B'), ]:
                     scs = [ [sc.points[0],sc.points[-1],sc.startPointValues,sc.endPointValues]
                            for i in matc
                            for sc in (cn.subContours[i],) ] # loop over 1-element list; basically local variable assignment
-                    print 'Start/end coords/values for '+ABstr+':', scs
+                    print('Start/end coords/values for '+ABstr+':', scs)
                 
                 scA,scB = cnA.subContours[a],cnB.subContours[b]
                 notRecoverableA += matchA
@@ -1165,8 +1165,8 @@ def FindMatchesAndRemovals(cnA,cnB):
                     removeA += matchA
                     removeB += matchB
                 elif len(matchInds)>1:
-                    print 'Not recoverable'
-                    print "sc's matches multiple sc's in opposing list " + multiFailString,pair,matchA,matchB
+                    print('Not recoverable')
+                    print("sc's matches multiple sc's in opposing list " + multiFailString,pair,matchA,matchB)
                     notRecoverableA += matchA
                     notRecoverableB += matchB
     
@@ -1189,17 +1189,17 @@ def FindMatchesAndRemovals(cnA,cnB):
             if len(matchInds)==1:
                 removeX += match
             elif len(matchInds)>1:
-                print 'Not recoverable'
-                print "sc in "+name+" matches multiple 4-junctions in "+otherName+":",pair,match
+                print('Not recoverable')
+                print("sc in "+name+" matches multiple 4-junctions in "+otherName+":",pair,match)
                 notRecoverableX += match
     
     # Anything that didn't get matched (and then deleted) get flagged as notRecoverable
     remainingPairsA = flatten(pairGroupsA.values())
     remainingPairsB = flatten(pairGroupsB.values())
     if len(remainingPairsA)+len(remainingPairsB)>0:
-        print 'Not Recoverable! No matches found!'
-        print 'A:', [ (i,cnA.subContours[i].values) for i in remainingPairsA ]
-        print 'B:', [ (i,cnB.subContours[i].values) for i in remainingPairsB ]
+        print('Not Recoverable! No matches found!')
+        print('A:', [ (i,cnA.subContours[i].values) for i in remainingPairsA ])
+        print('B:', [ (i,cnB.subContours[i].values) for i in remainingPairsB ])
         notRecoverableA += remainingPairsA
         notRecoverableB += remainingPairsB
     
@@ -1225,10 +1225,10 @@ def GetMatchedCellNetworksCollapsing(cnA,cnB):
     matchedA,matchedB, removeA,removeB, notRecoverableA,notRecoverableB = FindMatchesAndRemovals(cnA,cnB)
     
     if len(notRecoverableA)+len(notRecoverableB) > 0:
-        print 'Summary of pairs that are not recoverable from A:',notRecoverableA
-        print 'Summary of pairs that are not recoverable from B:',notRecoverableB
+        print('Summary of pairs that are not recoverable from A:',notRecoverableA)
+        print('Summary of pairs that are not recoverable from B:',notRecoverableB)
     else:
-        print 'All pairs matched.'
+        print('All pairs matched.')
     
     cnA.RemoveMultipleSubContours(removeA)
     cnB.RemoveMultipleSubContours(removeB)
@@ -1259,7 +1259,7 @@ def GetCellNetworkListStatic( waterArr,d,extraRemoveValsByFrame=None,forceRemake
                       for i in waterArr ] # Skip background
     
     ### Ensure that this has enough elements, if not, add more empty lists
-    if extraRemoveValsByFrame==None:
+    if extraRemoveValsByFrame is None:
         extraRemoveValsByFrame = []
     
     # Ensure we got a list-of-lists for extraRemovalsByFrame
@@ -1274,21 +1274,21 @@ def GetCellNetworkListStatic( waterArr,d,extraRemoveValsByFrame=None,forceRemake
     loadCnListFromFile = os.path.exists(cnListStaticFile) and not any(extraRemoveValsByFrame) and not forceRemake
     
     if loadCnListFromFile:
-        print 'Reloading cnLists from file:',cnListStaticFile
+        print('Reloading cnLists from file:',cnListStaticFile)
         
         # Load cnList from JSON file
         cnList = _loadCNListStaticFromJsonFile(cnListStaticFile)
         #cnList = cPickle.load(open(cnListStaticFile,'r')) # old pickle version
         
         if len(cnList)!=len(waterArr):
-            print 'cnList is the wrong length in the file:',cnListStaticFile
-            print 'Will remake them'
+            print('cnList is the wrong length in the file:',cnListStaticFile)
+            print('Will remake them')
             loadCnListFromFile=False
     if not loadCnListFromFile:
         ### The actual code that makes the cnList from scratch
         cnList = []
         for i in range(len(waterArr)):
-            print 'Generating CellNetwork for frame: %i' % i
+            print('Generating CellNetwork for frame: %i' % i)
             water = np.array(waterArr[i])
             valsToKeep = sorted( set(allValsByFrame[i]).difference(extraRemoveValsByFrame[i]) )
             for v in sorted(extraRemoveValsByFrame[i]):
@@ -1299,7 +1299,7 @@ def GetCellNetworkListStatic( waterArr,d,extraRemoveValsByFrame=None,forceRemake
         
         # Only save this if we're using all the values; otherwise it gets confusing!
         if not any(extraRemoveValsByFrame):
-            print 'Saving cnList to file:',cnListStaticFile
+            print('Saving cnList to file:',cnListStaticFile)
             # Save cnList to JSON file
             with open(cnListStaticFile,'w') as fid:
                 json.dump( [ GetFlatDataFromCellNetwork(cn) for cn in cnList ], fid )
@@ -1336,7 +1336,7 @@ def GetCVDListStatic( waterArr,d,useStaticAnalysis,
     cvdList = GetCVDListFromCellNetworkList(cnListLim)
     
     if usePlot:
-        print 'Plotting the subContours:'
+        print('Plotting the subContours:')
         cnList[0].scPlotT('r-')
         cnListLim[0].scPlotT('ro-')
     
@@ -1358,7 +1358,7 @@ def GetMatchedCellNetworkListsPrevNext( waterArr,d,extraRemoveValsByFrame=None,f
                       for i in waterArr ] # Skip background
     
     # Ensure that this has enough elements, if not, add more empty lists
-    if extraRemoveValsByFrame==None:
+    if extraRemoveValsByFrame is None:
         extraRemoveValsByFrame = []
     
     # Ensure we got a list-of-lists for extraRemovalsByFrame
@@ -1372,15 +1372,15 @@ def GetMatchedCellNetworkListsPrevNext( waterArr,d,extraRemoveValsByFrame=None,f
     loadCnListFromFile = os.path.exists(cnListPrevAndNextFile) and not any(extraRemoveValsByFrame) and not forceRemake
     
     if loadCnListFromFile:
-        print 'Reloading cnLists from file:',cnListPrevAndNextFile
+        print('Reloading cnLists from file:',cnListPrevAndNextFile)
         
         # Load cnListPrev and cnListNext from JSON file
         cnListPrev,cnListNext = _loadCNListPrevNextFromJsonFile(cnListPrevAndNextFile)
         #cnListPrev,cnListNext = cPickle.load(open(cnListPrevAndNextFile,'r')) # old pickle version
         
         if len(cnListPrev)!=len(waterArr)-1:
-            print 'cnLists are the wrong length in the file:',cnListPrevAndNextFile
-            print 'Will remake them'
+            print('cnLists are the wrong length in the file:',cnListPrevAndNextFile)
+            print('Will remake them')
             loadCnListFromFile=False
     
     allMatched = True
@@ -1391,7 +1391,7 @@ def GetMatchedCellNetworkListsPrevNext( waterArr,d,extraRemoveValsByFrame=None,f
         badFramePairs = []
         
         for i in range(len(waterArr)-1):
-            print 'Matching frames %i and %i' % (i,i+1)
+            print('Matching frames %i and %i' % (i,i+1))
             # create matched arrays first:
             waterA,waterB = np.array(waterArr[i]) , np.array(waterArr[i+1])
             extraRemovalsAB = set(extraRemoveValsByFrame[i]).union(extraRemoveValsByFrame[i+1])
@@ -1414,11 +1414,11 @@ def GetMatchedCellNetworkListsPrevNext( waterArr,d,extraRemoveValsByFrame=None,f
                 allMatched=False
                 badFramePairs.append( (i,i+1) )
         if not allMatched:
-            print 'Matching Errors! Will save cnLists to file, but these frames did not match:'
-            print badFramePairs
+            print('Matching Errors! Will save cnLists to file, but these frames did not match:')
+            print(badFramePairs)
         if not any(extraRemoveValsByFrame):
             # Only save this if we're using all the values; otherwise it gets confusing!
-            print 'Saving cnLists to file:',cnListPrevAndNextFile
+            print('Saving cnLists to file:',cnListPrevAndNextFile)
             
             # Save cnListPrev and cnListNext to JSON file
             with open(cnListPrevAndNextFile,'w') as fid:
@@ -1458,7 +1458,7 @@ def GetMatchedCVDListPrevNext( waterArr,d,useStaticAnalysis,
     cvdListNext = GetCVDListFromCellNetworkList(cnListNextLim)
     
     if usePlot:
-        print 'Plotting the subContours:'
+        print('Plotting the subContours:')
         cnListPrev[0].scPlotT('r-')
         cnListNext[0].scPlotT('b-')
         cnListPrevLim[0].scPlotT('ro-')
@@ -1602,7 +1602,7 @@ def GetEdgeGroups(edges,valuePairs,eliminateSameCellBoundaries=True):
        on either side are acutally the same; this should only occur at wrapped edges.'''
     edgeGroups = groupByFunction( zip(edges.tolist(),np.sort(valuePairs).tolist()),
                                   compose(tuple,itemgetter(1)), itemgetter(0) )
-    return ( { k:v for k,v in edgeGroups.iteritems() if k[0]!=k[1] }
+    return ( { k:v for k,v in edgeGroups.items() if k[0]!=k[1] }
              if eliminateSameCellBoundaries else
              edgeGroups )
 
@@ -1646,7 +1646,7 @@ def GetContourOrderingByValue(cellIDs,subContourValues,subContourPoints):
         if chainDirection==-1:
             scOrder = scOrder[::-1]
             scDirection = [ (not i) for i in scDirection ][::-1]
-        contourOrderingByValue[cellID] = zip(scOrder,scDirection)
+        contourOrderingByValue[cellID] = list(zip(scOrder,scDirection))
     return contourOrderingByValue
 
 
@@ -1679,7 +1679,7 @@ def GetCellNetwork_NEW( watershed2d,allValues=None,bgVals=(0,1),scale=1,offset=(
        '''
     arr = watershed2d # synonym
     cellIDs = deletecases( ( np.unique(arr)
-                             if allValues==None else         # rebuild allValues if None is passed
+                             if allValues is None else         # rebuild allValues if None is passed
                              np.array(allValues) ).tolist(), # force numpy array to list
                            bgVals )                          # remove background values
     
@@ -1707,7 +1707,7 @@ def GetCellNetwork_NEW( watershed2d,allValues=None,bgVals=(0,1),scale=1,offset=(
     cellBoundariesMulti = { k:getChainsFromConnections( getElementConnections(totuple(v)) )
                             for k,v in edgeGroups.items() }
     assert all( len(i)==1 for i in cellBoundariesMulti.values() ),'Some cells touch in multiple places'
-    cellBoundaries = { k:v[0] for k,v in cellBoundariesMulti.iteritems() } # We should be able to deal with one chain per cell pair
+    cellBoundaries = { k:v[0] for k,v in cellBoundariesMulti.items() } # We should be able to deal with one chain per cell pair
     scPtsByPairID = cellBoundaries
     if collapsePoles:
         # Eliminate all edges on the poles:
@@ -1718,9 +1718,9 @@ def GetCellNetwork_NEW( watershed2d,allValues=None,bgVals=(0,1),scale=1,offset=(
                                          p )
                                       for p in pts ]
         scPtsByPairID = { k : removeAdjacentDuplicates(_collapsePoles(pts))
-                         for k,pts in scPtsByPairID.iteritems() }
+                         for k,pts in scPtsByPairID.items() }
     if deleteZeroContours:
-        scPtsByPairID = { k:pts for k,pts in scPtsByPairID.iteritems()
+        scPtsByPairID = { k:pts for k,pts in scPtsByPairID.items()
                                 if 0 not in k }
 
     subContourValues,subContourPoints = ziptranspose(scPtsByPairID.items())
@@ -1777,7 +1777,7 @@ def getPointsEdgesCellsFromCellNetwork(cn,arr):
     orderedPointIDsByCell = { k:[ pindDict[tuple(i)]
                                  for i in v ]
                              for k,v in orderedPointsByCell.items() }
-    pointPairsByCell = { k:map(tuple,map(sorted,zip(v,roll(v))))
+    pointPairsByCell = { k:list(map(tuple,map(sorted,zip(v,roll(v)))))
                         for k,v in orderedPointIDsByCell.items() }
     edgesByCell = [ [k,[ eindDict[i]
                        for i in v
@@ -1787,7 +1787,7 @@ def getPointsEdgesCellsFromCellNetwork(cn,arr):
                  for k,v in pointPairsByCell.items()
                  for i in v
                  if i not in eindDict ]
-    print BAD_PAIRS, 'Not sure why these are here... ignored for the time being!'
+    print(BAD_PAIRS, 'Not sure why these are here... ignored for the time being!')
     
     return allPoints,allEdgesAsPtIDs,allCellsAsEdgeIDs
 
